@@ -49,11 +49,6 @@ BEGIN {
        exists $bar{\*baz};
      },
 
-     sub {
-       delete $bar{\*baz};
-       &null ($bar{\*baz});
-     },
-
      sub {
        %bar = (\*heh, 45);
        &equal (&symbol_plist (\*bar), [\*heh, 45]);
